jenkins-bot has submitted this change and it was merged. (
https://gerrit.wikimedia.org/r/403703 )
Change subject: JobQueue: Use EventBus for HTMLCacheUpdate except en, commons,
wikidata
......................................................................
JobQueue: Use EventBus for HTMLCacheUpdate except en, commons, wikidata
This is a second step towards integrating htmlCacheUpdate jobs into the
EventBus system. With this commit we switch them for all wikis but
enwiki, commonswiki and wikidatawiki, meaning that 50% of jobs will run
on the old infra and the other 50% will run on EventBus.
Bug: T182023
Change-Id: I31cc990b3baf7914236b7b56aea8c2ff8102cc07
---
M wmf-config/InitialiseSettings.php
1 file changed, 11 insertions(+), 12 deletions(-)
Approvals:
Mobrovac: Looks good to me, approved
jenkins-bot: Verified
diff --git a/wmf-config/InitialiseSettings.php
b/wmf-config/InitialiseSettings.php
index e5792d7..9767eb5 100644
--- a/wmf-config/InitialiseSettings.php
+++ b/wmf-config/InitialiseSettings.php
@@ -19655,19 +19655,18 @@
'votewiki' => false,
],
// Temporary code for the first test of htmlCacheUpdate
// on the EventBus JobQueue -disable old queue on wiktionaries only
'wmgDisableHTMLCacheUpdateInRedis' => [
- 'default' => false,
- 'cebwiki' => true,
- 'ruwiki' => true,
- 'wikibooks' => true,
- 'wikinews' => true,
- 'wikiquote' => true,
- 'wikisource' => true,
- 'wikiversity' => true,
- 'wikivoyage' => true,
- 'wiktionary' => true,
+ 'default' => true,
+ 'wikitech' => false,
+ 'private' => false,
+ 'loginwiki' => false,
+ 'votewiki' => false,
+ 'commonswiki' => false,
+ 'enwiki' => false,
+ 'wikidatawiki' => false,
],
'wmgUseCapiunto' => [
@@ -19655,19 +19655,18 @@
'votewiki' => false,
],
-// Temporary code for the first test of htmlCacheUpdate
-// on the EventBus JobQueue -disable old queue on wiktionaries only
+// Temporary code for gradually integrating htmlCacheUpdate
+// jobs into the EventBus JobQueue - T182023
+// Step 2: enable everywhere but wikidata, enwiki and commons
'wmgDisableHTMLCacheUpdateInRedis' => [
--
To view, visit https://gerrit.wikimedia.org/r/403703
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings
Gerrit-MessageType: merged
Gerrit-Change-Id: I31cc990b3baf7914236b7b56aea8c2ff8102cc07
Gerrit-PatchSet: 2
Gerrit-Project: operations/mediawiki-config
Gerrit-Branch: master
Gerrit-Owner: Mobrovac <[email protected]>
Gerrit-Reviewer: Giuseppe Lavagetto <[email protected]>
Gerrit-Reviewer: Mobrovac <[email protected]>
Gerrit-Reviewer: Ppchelko <[email protected]>
Gerrit-Reviewer: Urbanecm <[email protected]>
Gerrit-Reviewer: Zoranzoki21 <[email protected]>
Gerrit-Reviewer: jenkins-bot <>
_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits